#!/usr/bin/php
<?php

define('JAR_TYPE_FEATURES', 'features');
define('JAR_TYPE_PLUGINS',  'plugins');

/**
 * @var Site zip file
 */
if ($argc < 2) {
	echo "Usage: php site2dropin <site_file> [<dropin_dir>] [<arch>]\n";
	exit(1);
}

function extract_jars($items, $site_dir, $target_dir, $arch, $type)
{
	$jar = new ZipArchive();

	foreach ($items as $item) {
		if (isset($item['url']) && $item['url']) {
			$url = $item['url'];
			$dir = $target_dir . '/' . substr($item['url'], 0, strrpos($item['url'], '.'));
		} else {
			$url = $type . '/' . $item['id'] . '_' . $item['version'] . '.jar';
			$dir = $target_dir . '/' . $type . '/' . $item['id'] . '_' . $item['version'];
		}

		if (file_exists($dir)) {
			echo "NOTICE: dir '{$dir}' already exists\n";
			continue;
		}

		if (isset($item['os']) && $item['os'] && stripos($item['os'], 'linux') === false) {
			echo "NOTICE: Skipping .jar for OS '{$item['os']}'\n";
			continue;
		} elseif (isset($item['arch']) && $item['arch'] && strpos($item['arch'], $arch) === false) {
			echo "NOTICE: Skipping .jar for architecture '{$item['arch']}'\n";
			continue;
		}

		if (!file_exists($site_dir . '/' . $url))
		{
			echo "NOTICE: Couldn't find {$site_dir}/{$url}\n";
			continue;
		}

		if(!isset($item['unpack']) || $item['unpack'] === 'true') {
			if ($jar->open($site_dir . '/' . $url) !== true) {
				echo "ERROR: Unable to open feature jar: {$site_dir}/{$url}\n";
				exit(1);
			}

			echo "INFO: Extracting {$url}...\n";
			$jar->extractTo($dir);
			$jar->close();
		} else {
			echo "INFO: Copying {$url} => {$target_dir}/{$url}\n";
			exec("cp -r \"{$site_dir}/{$url}\" {$target_dir}/{$url}");
		}

		if($type == JAR_TYPE_FEATURES) {
			echo "INFO: Reading {$dir}/feature.xml...\n";
			if(!file_exists($dir . '/feature.xml')) {
				echo "ERROR: Unable to open {$dir}/feature.xml";
				exit(1);
			}
			$xml = simplexml_load_file($dir . '/feature.xml');

			echo "INFO: Extracting " . JAR_TYPE_PLUGINS . " for {$dir}\n";
			extract_jars($xml->plugin, $site_dir, $target_dir, $arch, JAR_TYPE_PLUGINS);
			echo "INFO: Extracting " . JAR_TYPE_FEATURES . " for {$dir}\n";
			extract_jars($xml->includes, $site_dir, $target_dir, $arch, JAR_TYPE_FEATURES);
		}
	}
}

$site_file = $argv[1];
if (array_key_exists(2, $argv)) {
	$tmp_dir = $argv[2];
} else {
	$tmp_dir = "./tmp";
}

if (array_key_exists(3,$argv)) {
	switch ($argv[3]) {
		case 'i386':
			$arch = 'x86';
			break;
		case 'amd64':
			$arch = 'x86_64';
			break;
		case 'powerpc':
			$arch = 'ppc';
			break;
		default:
			$arch = $argv[3];
	}
} else {
	$arch = "x86";
}

$target_dir = "{$tmp_dir}/eclipse";

if (file_exists($tmp_dir)) {
	echo "NOTICE: Cleaning up...\n";
	exec("rm -r {$tmp_dir}");
}

mkdir($tmp_dir);
mkdir($target_dir);
mkdir($target_dir . '/features');
mkdir($target_dir . '/plugins');

if (is_file($site_file)) {
	$site_dir = $tmp_dir . '/site';
	$site_zip = new ZipArchive();

	if ($site_zip->open($site_file) !== true) {
		echo "ERROR: Unable to open '{$site_file}'\n";
		exit(1);
	}

	$site_zip->extractTo($site_dir);
	$site_zip->close();
} elseif (is_dir($site_file)) {
	$site_dir = $site_file;
} else {
	echo "ERROR: Couldn't find update site '{$site_file}'\n";
	exit(1);
}

echo "INFO: Reading site.xml...\n";
$site_xml = simplexml_load_file($site_dir . '/site.xml');

extract_jars($site_xml->feature, $site_dir, $target_dir, $arch, JAR_TYPE_FEATURES);

?>
